==> babel-plugin-1.0.4.tgz: package/lib/esm/index.js <==
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import { declare } from '@babel/helper-plugin-utils';
import addSourceMaps from './sourceMap';
const sourceMapProperty = 'sourceMap';
export default declare(api => {
  const t = api.types;
  api.assertVersion(7);
  let readyImport = false;
  return {
    name: '@styils/babel-plugin',

    manipulateOptions(_, parserOpts) {
      const _ref = parserOpts,
            plugins = _ref.plugins;
      plugins.forEach((plugin, index) => {
        if (plugin === 'jsx') plugins.splice(index, 1);
      });
      plugins.forEach((plugin, index) => {
        const name = Array.isArray(plugin) ? plugin[0] : plugin;
        if (name === 'flow') plugins.splice(index, 1);
      });
      plugins.push('jsx', 'typescript', 'classProperties');
    },

    visitor: {
      Program: {
        enter(_, state) {
          var _state$opts$identifie;

          if (!state.opts.importPaths) {
            state.opts.importPaths = '@styils/react';
          }

          state.opts.identifier = _objectSpread({
            styled: 'styled',
            global: 'global'
          }, (_state$opts$identifie = state.opts.identifier) !== null && _state$opts$identifie !== void 0 ? _state$opts$identifie : {});
        }

      },

      ImportDeclaration(path, state) {
        const importPaths = state.opts.importPaths;

        if (importPaths) {
          const isImport = typeof importPaths === 'string' ? importPaths === path.node.source.value : importPaths.test(path.node.source.value);

          if (isImport) {
            readyImport = path.node.specifiers.some(childNode => {
              return state.opts.identifier[childNode.local.name];
            });
          }
        }
      },

      CallExpression(path, state) {
        var _ref2, _state$file$opts$file, _ref3, _state$file$opts$sour;

        const sourceFileName = (_ref2 = (_state$file$opts$file = state.file.opts.filename) !== null && _state$file$opts$file !== void 0 ? _state$file$opts$file : state.file.opts.sourceFileName) !== null && _ref2 !== void 0 ? _ref2 : state.opts.sourceFileName;
        const sourceRoot = (_ref3 = (_state$file$opts$sour = state.file.opts.sourceRoot) !== null && _state$file$opts$sour !== void 0 ? _state$file$opts$sour : state.opts.sourceRoot) !== null && _ref3 !== void 0 ? _ref3 : '';

        if (!sourceFileName) {
          throw new Error('To compile using api, you need to pass in `sourceFileName`');
        }

        if (readyImport && t.isIdentifier(path.node.callee) && state.opts.identifier && state.opts.identifier[path.node.callee.name] && path.node.loc) {
          let parent = null;

          if (path.node.callee.name === state.opts.identifier.styled) {
            parent = path.findParent(parent => parent.isVariableDeclaration());
          } else if (path.node.callee.name === state.opts.identifier.global) {
            parent = path.findParent(parent => parent.isExpressionStatement());
          }

          if (parent) {
            const sourceMapNode = t.logicalExpression('&&', t.binaryExpression('!==', t.memberExpression(t.memberExpression(t.identifier('process'), t.identifier('env')), t.identifier('NODE_ENV')), t.stringLiteral('production')), t.assignmentExpression('=', t.memberExpression(t.identifier(path.node.callee.name), t.identifier(sourceMapProperty)), t.stringLiteral(addSourceMaps(path.node.loc.start, {
              sourceFileName,
              sourceRoot,
              code: state.file.code
            }))));
            parent.insertBefore(sourceMapNode);
          }
        }
      }

    }
  };
});

==> babel-plugin-1.0.5.tgz: package/lib/esm/index.js <==
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import { declare } from '@babel/helper-plugin-utils';
import addSourceMaps from './sourceMap';
const sourceMapProperty = 'sourceMap';
export default declare(api => {
  const t = api.types;
  api.assertVersion(7);
  let readyImport = false;
  return {
    name: '@styils/babel-plugin',

    manipulateOptions(_, parserOpts) {
      const _ref = parserOpts,
            plugins = _ref.plugins;
      plugins.forEach((plugin, index) => {
        if (plugin === 'jsx') plugins.splice(index, 1);
      });
      plugins.forEach((plugin, index) => {
        const name = Array.isArray(plugin) ? plugin[0] : plugin;
        if (name === 'flow') plugins.splice(index, 1);
      });
      plugins.push('jsx', 'typescript', 'classProperties');
    },

    visitor: {
      Program: {
        enter(_, state) {
          var _state$opts$identifie;

          if (!state.opts.importPaths) {
            state.opts.importPaths = /@styils\/(react|solid)/;
          }

          state.opts.identifier = _objectSpread({
            styled: 'styled',
            global: 'global'
          }, (_state$opts$identifie = state.opts.identifier) !== null && _state$opts$identifie !== void 0 ? _state$opts$identifie : {});
        }

      },

      ImportDeclaration(path, state) {
        const importPaths = state.opts.importPaths;

        if (importPaths) {
          const isImport = typeof importPaths === 'string' ? importPaths === path.node.source.value : importPaths.test(path.node.source.value);

          if (isImport) {
            readyImport = path.node.specifiers.some(childNode => {
              return state.opts.identifier[childNode.local.name];
            });
          }
        }
      },

      CallExpression(path, state) {
        var _ref2, _state$file$opts$file, _ref3, _state$file$opts$sour;

        const sourceFileName = (_ref2 = (_state$file$opts$file = state.file.opts.filename) !== null && _state$file$opts$file !== void 0 ? _state$file$opts$file : state.file.opts.sourceFileName) !== null && _ref2 !== void 0 ? _ref2 : state.opts.sourceFileName;
        const sourceRoot = (_ref3 = (_state$file$opts$sour = state.file.opts.sourceRoot) !== null && _state$file$opts$sour !== void 0 ? _state$file$opts$sour : state.opts.sourceRoot) !== null && _ref3 !== void 0 ? _ref3 : '';

        if (!sourceFileName) {
          throw new Error('To compile using api, you need to pass in `sourceFileName`');
        }

        if (readyImport && t.isIdentifier(path.node.callee) && state.opts.identifier && state.opts.identifier[path.node.callee.name] && path.node.loc) {
          let parent = null;

          if (path.node.callee.name === state.opts.identifier.styled) {
            parent = path.findParent(parent => parent.isVariableDeclaration());
          } else if (path.node.callee.name === state.opts.identifier.global) {
            parent = path.findParent(parent => parent.isExpressionStatement());
          }

          if (parent) {
            const sourceMapNode = t.logicalExpression('&&', t.binaryExpression('!==', t.memberExpression(t.memberExpression(t.identifier('process'), t.identifier('env')), t.identifier('NODE_ENV')), t.stringLiteral('production')), t.assignmentExpression('=', t.memberExpression(t.identifier(path.node.callee.name), t.identifier(sourceMapProperty)), t.stringLiteral(addSourceMaps(path.node.loc.start, {
              sourceFileName,
              sourceRoot,
              code: state.file.code
            }))));
            parent.insertBefore(sourceMapNode);
          }
        }
      }

    }
  };
});
